package com.example.firstapp.adapter

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.DiffUtil
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.ListAdapter
import androidx.recyclerview.widget.RecyclerView
import com.example.firstapp.R
import com.example.firstapp.databinding.ItemTrainGroupBinding
import com.example.firstapp.databinding.ItemTrainPackageHomeBinding
import com.example.firstapp.databinding.ItemTrainBinding
import com.example.firstapp.model.TrainGroup
import com.example.firstapp.model.TrainPackage

class TrainAdapter :
    ListAdapter<TrainGroup, TrainAdapter.ViewHolder>(TrainGroupDiffCallback()) {

    private var onPackageClickListener: (TrainGroup, TrainPackage) -> Unit = { _, _ -> }

    fun setOnPackageClickListener(listener: (TrainGroup, TrainPackage) -> Unit) {
        onPackageClickListener = listener
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val binding = ItemTrainGroupBinding.inflate(
            LayoutInflater.from(parent.context), parent, false
        )
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val group = getItem(position)
        holder.bind(group)
        holder.setOnPackageClickListener(onPackageClickListener)
    }


    inner class ViewHolder(private val binding: ItemTrainGroupBinding) :
        RecyclerView.ViewHolder(binding.root) {
        private val packagesAdapter = TrainPackageHomeAdapter { pack ->
            currentGroup?.let { group ->
                onPackageClickListener(group, pack)
            }
        }
        private var currentGroup: TrainGroup? = null

        init {
            binding.rvPackages.apply {
                layoutManager = LinearLayoutManager(context)
                adapter = packagesAdapter
            }
        }

        fun bind(group: TrainGroup) {
            currentGroup = group
            binding.tvStationName.text = group.stationName
            binding.tvPackageCount.text = "共${group.packages.size}张车票"
            packagesAdapter.submitList(group.packages)
        }

        fun setOnPackageClickListener(listener: (TrainGroup, TrainPackage) -> Unit) {
            // 这个方法可以移除，因为我们在构造 TrainPackageHomeAdapter 时已经处理了点击事件
            // 或者保留这个方法但不做任何操作
        }
    }
}

// 首页使用的车票适配器 - 简化版本
class TrainPackageHomeAdapter(private val onPackageClick: (TrainPackage) -> Unit) :
    ListAdapter<TrainPackage, TrainPackageHomeAdapter.ViewHolder>(TrainPackageDiffCallback()) {

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val binding = ItemTrainPackageHomeBinding.inflate(
            LayoutInflater.from(parent.context), parent, false
        )
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val pack = getItem(position)
        holder.bind(pack)
    }

    inner class ViewHolder(private val binding: ItemTrainPackageHomeBinding) :
        RecyclerView.ViewHolder(binding.root) {

        init {
            binding.root.setOnClickListener {
                val pack = getItem(adapterPosition)
                onPackageClick(pack)
            }
        }

        fun bind(pack: TrainPackage) {
            binding.tvCompany.text = pack.company
            binding.tvCreateTime.text = pack.createTime
            binding.tvTrackingNumber.text = pack.trackingNumber
        }
    }
}

// 取件页面使用的车票适配器
class TrainPackageAdapter(private val onPackagePickup: (TrainPackage) -> Unit = { _ -> }) :
    ListAdapter<TrainPackage, TrainPackageAdapter.ViewHolder>(TrainPackageDiffCallback()) {

    private var onPackageClickListener: (TrainPackage) -> Unit = {}
    private var stationName: String = ""

    fun setStationInfo(station: String) {
        stationName = station
    }

    fun setOnPackageClickListener(listener: (TrainPackage) -> Unit) {
        onPackageClickListener = listener
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val binding = ItemTrainBinding.inflate(
            LayoutInflater.from(parent.context), parent, false
        )
        return ViewHolder(binding)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val pack = getItem(position)
        holder.bind(pack)
    }

    inner class ViewHolder(private val binding: ItemTrainBinding) :
        RecyclerView.ViewHolder(binding.root) {

        init {
            binding.ivPackageStatus.setOnClickListener {
                val pack = getItem(adapterPosition)
                onPackagePickup(pack)
            }

            binding.root.setOnClickListener(null)
        }

        fun bind(pack: TrainPackage) {
            binding.tvPackageId.text = pack.id.toString()
            binding.tvCompany.text = pack.company
            binding.tvCreateTime.text = pack.createTime
            binding.tvTrackingNumber.text = pack.trackingNumber
            binding.ivPackageStatus.setImageResource(
                R.drawable.circle
            )
        }
    }
}


private class TrainGroupDiffCallback : DiffUtil.ItemCallback<TrainGroup>() {
    override fun areItemsTheSame(oldItem: TrainGroup, newItem: TrainGroup): Boolean {
        return oldItem.stationName == newItem.stationName
    }

    override fun areContentsTheSame(oldItem: TrainGroup, newItem: TrainGroup): Boolean {
        return oldItem == newItem
    }
}

private class TrainPackageDiffCallback : DiffUtil.ItemCallback<TrainPackage>() {
    override fun areItemsTheSame(oldItem: TrainPackage, newItem: TrainPackage): Boolean {
        return oldItem.trackingNumber == newItem.trackingNumber
    }

    override fun areContentsTheSame(oldItem: TrainPackage, newItem: TrainPackage): Boolean {
        return oldItem == newItem
    }
} 